from PyQt5.QtWidgets import QMessageBox


def valid_url(self):
    QMessageBox.warning(self, "Error", "Please enter a valid URL", QMessageBox.Ok)


def json_error(self):
    QMessageBox.information(self, "Error", "This site has no REST API", QMessageBox.Ok)


def empty_request(self):
    QMessageBox.information(self, "Error", "Please send a request first", QMessageBox.Ok)



import json
import sys
import webbrowser

import requests
from PyQt5 import QtCore
from PyQt5.QtWidgets import QApplication, QMainWindow, QTableWidgetItem, QFileDialog

from PySender.dialogs import open_about_dialog
from PySender.errors import *
from PySender.request import Request
from PySender.ui.ui import Ui_MainWindow


class MyWidget(QMainWindow, Ui_MainWindow):
    def __init__(self):
        super().__init__()
        self.setupUi(self)
        self.button_send.clicked.connect(self.send_request)
        self.button_add.clicked.connect(self.add_header)
        self.delete_header_button.clicked.connect(self.remove_header)
        self.clear_button.clicked.connect(self.clear_headers)
        self.actionAbout.triggered.connect(open_about_dialog)
        self.actionSupport.triggered.connect(lambda: webbrowser.open('https://t.me/fast_geek'))
        self.actionExit.triggered.connect(lambda: exit(0))
        self.actionSave.triggered.connect(self.save_file)
        self.lineEdit_URL.installEventFilter(self)
        self.tabWidget.setCurrentIndex(0)

    def send_request(self):
        params = {}
        for i in range(self.table_headers.rowCount()):
            params[self.table_headers.item(i, 0).text()] = self.table_headers.item(i, 1).text()
        try:
            user, passwd = self.field_username.text(), self.field_password.text() if \
                self.field_username.text() != "" or self.field_password.text() != "" \
                else None
            url = self.lineEdit_URL.text()
            method = self.method_selector.currentText().lower()
            res, status_code = Request(url, method, user, passwd, params).send()
            self.field_response.setText(res)
            self.field_status_code.setText(str(status_code))
            self.tabWidget.setCurrentIndex(2)
        except requests.exceptions.MissingSchema:
            valid_url(self)
        except json.decoder.JSONDecodeError:
            json_error(self)

    def add_header(self):
        name = self.field_name.text().strip()
        value = self.field_value.text().strip()
        if "" in (name, value):
            QMessageBox.warning(self, "Error", "Please enter a valid header", QMessageBox.Ok)
        self.table_headers.setRowCount(self.table_headers.rowCount() + 1)
        self.table_headers.setItem(self.table_headers.rowCount() - 1, 0, QTableWidgetItem(name))
        self.table_headers.setItem(self.table_headers.rowCount() - 1, 1, QTableWidgetItem(value))
        self.field_name.setText("")
        self.field_value.setText("")

    def remove_header(self):
        if self.table_headers.currentRow() != -1:
            self.table_headers.removeRow(self.table_headers.currentRow())
        else:
            QMessageBox.warning(self, "Error", "Select the item you want to delete", QMessageBox.Ok)

    def clear_headers(self):
        self.table_headers.clearContents()
        self.table_headers.setRowCount(0)

    def eventFilter(self, obj, event):
        if (
                event.type() == QtCore.QEvent.KeyPress
                and obj is self.lineEdit_URL
                and event.key() == QtCore.Qt.Key_Return
                and self.lineEdit_URL.hasFocus()
        ):
            self.send_request()
        return super().eventFilter(obj, event)

    def save_file(self):
        if self.field_response.toPlainText() == "":
            empty_request(self)
        file_name = QFileDialog.getSaveFileName(self, "Save File", "", "Text Files (*.txt)")
        if file_name[0] != "":
            with open(file_name[0], "w") as f:
                f.write(f"TYPE: {self.method_selector.currentText()} \n")
                f.write(f"URL: {self.lineEdit_URL.text()} \n")
                f.write(f"STATUS CODE: {self.field_status_code.text()} \n")
                f.write(f"RESPONSE: {self.field_response.toPlainText()}")


def main():
    app = QApplication(sys.argv)
    ex = MyWidget()
    ex.show()
    sys.exit(app.exec_())


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1115, 884)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_method = QtWidgets.QLabel(self.centralwidget)
        self.label_method.setObjectName("label_method")
        self.horizontalLayout_3.addWidget(self.label_method)
        self.method_selector = QtWidgets.QComboBox(self.centralwidget)
        self.method_selector.setObjectName("method_selector")
        self.method_selector.addItem("")
        self.method_selector.addItem("")
        self.method_selector.addItem("")
        self.method_selector.addItem("")
        self.method_selector.addItem("")
        self.horizontalLayout_3.addWidget(self.method_selector)
        self.field_URL = QtWidgets.QLabel(self.centralwidget)
        self.field_URL.setObjectName("field_URL")
        self.horizontalLayout_3.addWidget(self.field_URL)
        self.lineEdit_URL = QtWidgets.QLineEdit(self.centralwidget)
        self.lineEdit_URL.setObjectName("lineEdit_URL")
        self.horizontalLayout_3.addWidget(self.lineEdit_URL)
        self.button_send = QtWidgets.QPushButton(self.centralwidget)
        self.button_send.setObjectName("button_send")
        self.horizontalLayout_3.addWidget(self.button_send)
        self.horizontalLayout_2.addLayout(self.horizontalLayout_3)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setObjectName("tabWidget")
        self.widget = QtWidgets.QWidget()
        self.widget.setObjectName("widget")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_3 = QtWidgets.QLabel(self.widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setStyleSheet("font: 18pt;")
        self.label_3.setObjectName("label_3")
        self.verticalLayout_2.addWidget(self.label_3, 0, QtCore.Qt.AlignTop)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label = QtWidgets.QLabel(self.widget)
        self.label.setObjectName("label")
        self.horizontalLayout_13.addWidget(self.label)
        self.auth_typ_cbox = QtWidgets.QComboBox(self.widget)
        self.auth_typ_cbox.setObjectName("auth_typ_cbox")
        self.auth_typ_cbox.addItem("")
        self.auth_typ_cbox.addItem("")
        self.horizontalLayout_13.addWidget(self.auth_typ_cbox)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem)
        self.verticalLayout_2.addLayout(self.horizontalLayout_13)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_username = QtWidgets.QLabel(self.widget)
        self.label_username.setObjectName("label_username")
        self.horizontalLayout_5.addWidget(self.label_username, 0, QtCore.Qt.AlignTop)
        self.field_username = QtWidgets.QLineEdit(self.widget)
        self.field_username.setObjectName("field_username")
        self.horizontalLayout_5.addWidget(self.field_username, 0, QtCore.Qt.AlignTop)
        self.label_password = QtWidgets.QLabel(self.widget)
        self.label_password.setObjectName("label_password")
        self.horizontalLayout_5.addWidget(self.label_password, 0, QtCore.Qt.AlignTop)
        self.field_password = QtWidgets.QLineEdit(self.widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.field_password.sizePolicy().hasHeightForWidth())
        self.field_password.setSizePolicy(sizePolicy)
        self.field_password.setObjectName("field_password")
        self.horizontalLayout_5.addWidget(self.field_password, 0, QtCore.Qt.AlignTop)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.verticalLayout_2.setStretch(0, 1)
        self.verticalLayout_2.setStretch(2, 100)
        self.horizontalLayout_4.addLayout(self.verticalLayout_2)
        self.tabWidget.addTab(self.widget, "")
        self.tab_9 = QtWidgets.QWidget()
        self.tab_9.setObjectName("tab_9")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.tab_9)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label_headers = QtWidgets.QLabel(self.tab_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_headers.sizePolicy().hasHeightForWidth())
        self.label_headers.setSizePolicy(sizePolicy)
        self.label_headers.setStyleSheet("font: 18pt;")
        self.label_headers.setObjectName("label_headers")
        self.verticalLayout_3.addWidget(self.label_headers, 0, QtCore.Qt.AlignTop)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_name = QtWidgets.QLabel(self.tab_9)
        self.label_name.setObjectName("label_name")
        self.horizontalLayout_7.addWidget(self.label_name, 0, QtCore.Qt.AlignTop)
        self.field_name = QtWidgets.QLineEdit(self.tab_9)
        self.field_name.setObjectName("field_name")
        self.horizontalLayout_7.addWidget(self.field_name, 0, QtCore.Qt.AlignTop)
        self.label_value = QtWidgets.QLabel(self.tab_9)
        self.label_value.setObjectName("label_value")
        self.horizontalLayout_7.addWidget(self.label_value, 0, QtCore.Qt.AlignTop)
        self.field_value = QtWidgets.QLineEdit(self.tab_9)
        self.field_value.setObjectName("field_value")
        self.horizontalLayout_7.addWidget(self.field_value, 0, QtCore.Qt.AlignTop)
        self.button_add = QtWidgets.QPushButton(self.tab_9)
        self.button_add.setObjectName("button_add")
        self.horizontalLayout_7.addWidget(self.button_add, 0, QtCore.Qt.AlignTop)
        self.verticalLayout_3.addLayout(self.horizontalLayout_7)
        self.table_headers = QtWidgets.QTableWidget(self.tab_9)
        self.table_headers.setObjectName("table_headers")
        self.table_headers.setColumnCount(2)
        self.table_headers.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.table_headers.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.table_headers.setHorizontalHeaderItem(1, item)
        self.table_headers.horizontalHeader().setStretchLastSection(True)
        self.verticalLayout_3.addWidget(self.table_headers)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.clear_button = QtWidgets.QPushButton(self.tab_9)
        self.clear_button.setObjectName("clear_button")
        self.horizontalLayout_10.addWidget(self.clear_button)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem1)
        self.delete_header_button = QtWidgets.QPushButton(self.tab_9)
        self.delete_header_button.setObjectName("delete_header_button")
        self.horizontalLayout_10.addWidget(self.delete_header_button)
        self.verticalLayout_3.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_6.addLayout(self.verticalLayout_3)
        self.tabWidget.addTab(self.tab_9, "")
        self.tab_8 = QtWidgets.QWidget()
        self.tab_8.setObjectName("tab_8")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.tab_8)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.label_2 = QtWidgets.QLabel(self.tab_8)
        self.label_2.setStyleSheet("font: 18pt;")
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_12.addWidget(self.label_2)
        self.status_code_label = QtWidgets.QLabel(self.tab_8)
        self.status_code_label.setObjectName("status_code_label")
        self.horizontalLayout_12.addWidget(self.status_code_label)
        self.field_status_code = QtWidgets.QLineEdit(self.tab_8)
        self.field_status_code.setReadOnly(True)
        self.field_status_code.setObjectName("field_status_code")
        self.horizontalLayout_12.addWidget(self.field_status_code)
        self.horizontalLayout_12.setStretch(0, 100)
        self.horizontalLayout_12.setStretch(2, 5)
        self.verticalLayout_5.addLayout(self.horizontalLayout_12)
        self.field_response = QtWidgets.QTextEdit(self.tab_8)
        self.field_response.setObjectName("field_response")
        self.verticalLayout_5.addWidget(self.field_response)
        self.horizontalLayout_9.addLayout(self.verticalLayout_5)
        self.tabWidget.addTab(self.tab_8, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.horizontalLayout.addLayout(self.verticalLayout)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1115, 24))
        self.menubar.setObjectName("menubar")
        self.menuProgram = QtWidgets.QMenu(self.menubar)
        self.menuProgram.setObjectName("menuProgram")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionSupport = QtWidgets.QAction(MainWindow)
        self.actionSupport.setObjectName("actionSupport")
        self.actionExit = QtWidgets.QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionSave = QtWidgets.QAction(MainWindow)
        self.actionSave.setObjectName("actionSave")
        self.actionOpen = QtWidgets.QAction(MainWindow)
        self.actionOpen.setObjectName("actionOpen")
        self.actionOpen_2 = QtWidgets.QAction(MainWindow)
        self.actionOpen_2.setObjectName("actionOpen_2")
        self.menuProgram.addAction(self.actionExit)
        self.menuHelp.addAction(self.actionAbout)
        self.menuHelp.addAction(self.actionSupport)
        self.menuFile.addAction(self.actionSave)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuProgram.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "PySender"))
        self.label_method.setText(_translate("MainWindow", "Method"))
        self.method_selector.setItemText(0, _translate("MainWindow", "GET"))
        self.method_selector.setItemText(1, _translate("MainWindow", "POST"))
        self.method_selector.setItemText(2, _translate("MainWindow", "PUT"))
        self.method_selector.setItemText(3, _translate("MainWindow", "PATCH"))
        self.method_selector.setItemText(4, _translate("MainWindow", "DELETE"))
        self.field_URL.setText(_translate("MainWindow", "URL"))
        self.button_send.setText(_translate("MainWindow", "Send"))
        self.label_3.setText(_translate("MainWindow", "Authentication "))
        self.label.setText(_translate("MainWindow", "Type"))
        self.auth_typ_cbox.setItemText(0, _translate("MainWindow", "Basic"))
        self.auth_typ_cbox.setItemText(1, _translate("MainWindow", "Digest"))
        self.label_username.setText(_translate("MainWindow", "Username"))
        self.label_password.setText(_translate("MainWindow", "Password"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.widget), _translate("MainWindow", "Authentication"))
        self.label_headers.setText(_translate("MainWindow", "Headers"))
        self.label_name.setText(_translate("MainWindow", "Name"))
        self.label_value.setText(_translate("MainWindow", "Value"))
        self.button_add.setText(_translate("MainWindow", "Add"))
        self.table_headers.setSortingEnabled(True)
        item = self.table_headers.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "Name"))
        item = self.table_headers.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "Value"))
        self.clear_button.setText(_translate("MainWindow", "Clear"))
        self.delete_header_button.setText(_translate("MainWindow", "Delete"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_9), _translate("MainWindow", "Headers"))
        self.label_2.setText(_translate("MainWindow", "Response"))
        self.status_code_label.setText(_translate("MainWindow", "Status code"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_8), _translate("MainWindow", "Response"))
        self.menuProgram.setTitle(_translate("MainWindow", "Program"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionSupport.setText(_translate("MainWindow", "Support"))
        self.actionExit.setText(_translate("MainWindow", "Exit"))
        self.actionSave.setText(_translate("MainWindow", "Save"))
        self.actionOpen.setText(_translate("MainWindow", "Open"))
        self.actionOpen_2.setText(_translate("MainWindow", "Open"))



import webbrowser

import PySender
from PyQt5 import QtCore
from PyQt5.QtWidgets import QDialog

from PySender.ui.about import Ui_Dialog


def open_about_dialog():
    dialog = QDialog()
    dialog.ui = Ui_Dialog()
    dialog.ui.setupUi(dialog)
    dialog.ui.label_version.setText(PySender.__version__)
    dialog.ui.github_button.clicked.connect(lambda: webbrowser.open('https://github.com/fast-geek/PySender'))
    dialog.ui.pypi_button.clicked.connect(lambda: webbrowser.open('https://pypi.org/project/PySender'))
    dialog.setAttribute(QtCore.Qt.WA_DeleteOnClose)
    dialog.exec_()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'about.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(722, 344)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        self.horizontalLayout = QtWidgets.QHBoxLayout(Dialog)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label = QtWidgets.QLabel(Dialog)
        self.label.setStyleSheet("font: 64pt")
        self.label.setObjectName("label")
        self.verticalLayout_3.addWidget(self.label, 0, QtCore.Qt.AlignHCenter|QtCore.Qt.AlignVCenter)
        self.label_7 = QtWidgets.QLabel(Dialog)
        self.label_7.setMaximumSize(QtCore.QSize(100, 100))
        self.label_7.setText("")
        self.label_7.setPixmap(QtGui.QPixmap("PySender/res/icon.png"))
        self.label_7.setScaledContents(True)
        self.label_7.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_7.setObjectName("label_7")
        self.verticalLayout_3.addWidget(self.label_7, 0, QtCore.Qt.AlignHCenter|QtCore.Qt.AlignVCenter)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.github_button = QtWidgets.QPushButton(Dialog)
        self.github_button.setAutoDefault(False)
        self.github_button.setObjectName("github_button")
        self.horizontalLayout_10.addWidget(self.github_button)
        self.pypi_button = QtWidgets.QPushButton(Dialog)
        self.pypi_button.setAutoDefault(False)
        self.pypi_button.setObjectName("pypi_button")
        self.horizontalLayout_10.addWidget(self.pypi_button)
        self.verticalLayout_3.addLayout(self.horizontalLayout_10)
        self.verticalLayout_3.setStretch(0, 5)
        self.verticalLayout_3.setStretch(2, 1)
        self.horizontalLayout_2.addLayout(self.verticalLayout_3)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_2 = QtWidgets.QLabel(Dialog)
        self.label_2.setStyleSheet("font: 24pt")
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_3.addWidget(self.label_2, 0, QtCore.Qt.AlignRight|QtCore.Qt.AlignTop)
        self.label_version = QtWidgets.QLabel(Dialog)
        self.label_version.setStyleSheet("font: 24pt")
        self.label_version.setText("")
        self.label_version.setObjectName("label_version")
        self.horizontalLayout_3.addWidget(self.label_version, 0, QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.horizontalLayout_3.setStretch(0, 1)
        self.horizontalLayout_3.setStretch(1, 1)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_3 = QtWidgets.QLabel(Dialog)
        self.label_3.setStyleSheet("font: 24pt")
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_4.addWidget(self.label_3, 0, QtCore.Qt.AlignRight|QtCore.Qt.AlignTop)
        self.label_4 = QtWidgets.QLabel(Dialog)
        self.label_4.setStyleSheet("font: 24pt")
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_4.addWidget(self.label_4, 0, QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.horizontalLayout_4.setStretch(0, 1)
        self.horizontalLayout_4.setStretch(1, 1)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_5 = QtWidgets.QLabel(Dialog)
        self.label_5.setStyleSheet("font: 24pt")
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_7.addWidget(self.label_5, 0, QtCore.Qt.AlignRight|QtCore.Qt.AlignTop)
        self.label_6 = QtWidgets.QLabel(Dialog)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_7.addWidget(self.label_6, 0, QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.horizontalLayout_7.setStretch(0, 1)
        self.horizontalLayout_7.setStretch(1, 1)
        self.verticalLayout_2.addLayout(self.horizontalLayout_7)
        self.verticalLayout_2.setStretch(0, 1)
        self.verticalLayout_2.setStretch(1, 3)
        self.verticalLayout_2.setStretch(2, 3)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.horizontalLayout.addLayout(self.verticalLayout)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "About"))
        self.label.setText(_translate("Dialog", "PySender"))
        self.github_button.setText(_translate("Dialog", "GitHub"))
        self.pypi_button.setText(_translate("Dialog", "PyPi"))
        self.label_2.setText(_translate("Dialog", "Version:"))
        self.label_3.setText(_translate("Dialog", "Libraries:"))
        self.label_4.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'.AppleSystemUIFont\'; font-size:24pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">- PyQt5</p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">- requests</p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">- sqlite3</p></body></html>"))
        self.label_5.setText(_translate("Dialog", "<html><head/><body><p>Author:</p></body></html>"))
        self.label_6.setText(_translate("Dialog", "<html><head/><body><p><span style=\" font-size:24pt;\">lavender</span></p><p><span style=\" font-size:24pt;\">(aka fast-geek)</span></p></body></html>"))



from setuptools import setup

from PySender.__version__ import __version__

with open("README.md") as f:
    long_description = f.read()

setup(
    name='PySender',
    version=__version__,
    packages=['PySender', 'PySender.ui'],
    include_package_data=True,
    license='MIT',
    author='lavender',
    author_email='support@lavender.ml',
    description='PyQt app to send REST API requests',
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords='python pyqt rest api',
    url='https://github.com/fast-geek/PySender',
    python_requires='>=3.6.1',
    package_data={'PySender': ['res/icon.png']},
    install_requires=[
        'PyQt5',
        'requests',
    ],
    entry_points={
        'console_scripts': [
            'PySender = PySender:main'
        ]
    },
    project_urls={
        "Homepage": "https://github.com/fast-geek/PySender",
        "Donate": "https://lavtg.ml/donat",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



import json

import requests


class Request:
    def __init__(self, url, method, user, passwd, params=None):
        self.url = url
        self.method = method
        self.user = user
        self.passwd = passwd
        self.params = params

    def send(self):
        request = getattr(requests, self.method)(self.url,
                                                 auth=(self.user, self.passwd),
                                                 **{"params" if self.method == "GET" else "data": self.params})
        res = json.dumps(request.json(), indent=2, sort_keys=True)
        status_code = request.status_code
        return res, status_code
